==> eam-wshub-proxyclient-11.4-6-sources.jar: net/datastream/schemas/mp_fields/COMMENTAUDITITEM_Type.java <==

package net.datastream.schemas.mp_fields;

import javax.xml.bind.annotation.XmlAccessType;
import javax.xml.bind.annotation.XmlAccessorType;
import javax.xml.bind.annotation.XmlElement;
import javax.xml.bind.annotation.XmlType;
import org.openapplications.oagis_segments.DATETIME;


/**
 * <p>Classe Java pour COMMENTAUDITITEM_Type complex type.
 * 
 * <p>Le fragment de schéma suivant indique le contenu attendu figurant dans cette classe.
 * 
 * <pre>
 * &lt;complexType name="COMMENTAUDITITEM_Type">
 *   &lt;complexContent>
 *     &lt;extension base="{http://schemas.datastream.net/MP_fields}COMMENT_Type">
 *       &lt;sequence>
 *         &lt;element name="DELETEDDATE" type="{http://www.openapplications.org/oagis_segments}DATETIME" minOccurs="0"/>
 *         &lt;element name="DELETEDBY" type="{http://schemas.datastream.net/MP_fields}USERID_Type" minOccurs="0"/>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}ISMOBILE" minOccurs="0"/>
 *       &lt;/sequence>
 *     &lt;/extension>
 *   &lt;/complexContent>
 * &lt;/complexType>
 * </pre>
 * 
 * 
 */
@XmlAccessorType(XmlAccessType.FIELD)
@XmlType(name = "COMMENTAUDITITEM_Type", propOrder = {
    "deleteddate",
    "deletedby",
    "ismobile"
})
public class COMMENTAUDITITEM_Type
    extends COMMENT_Type
{

    @XmlElement(name = "DELETEDDATE")
    protected DATETIME deleteddate;
    @XmlElement(name = "DELETEDBY")
    protected USERID_Type deletedby;
    @XmlElement(name = "ISMOBILE")
    protected String ismobile;

    /**
     * Obtient la valeur de la propriété deleteddate.
     * 
     * @return
     *     possible object is
     *     {@link DATETIME }
     *     
     */
    public DATETIME getDELETEDDATE() {
        return deleteddate;
    }

    /**
     * Définit la valeur de la propriété deleteddate.
     * 
     * @param value
     *     allowed object is
     *     {@link DATETIME }
     *     
     */
    public void setDELETEDDATE(DATETIME value) {
        this.deleteddate = value;
    }

    /**
     * Obtient la valeur de la propriété deletedby.
     * 
     * @return
     *     possible object is
     *     {@link USERID_Type }
     *     
     */
    public USERID_Type getDELETEDBY() {
        return deletedby;
    }

    /**
     * Définit la valeur de la propriété deletedby.
     * 
     * @param value
     *     allowed object is
     *     {@link USERID_Type }
     *     
     */
    public void setDELETEDBY(USERID_Type value) {
        this.deletedby = value;
    }

    /**
     * Obtient la valeur de la propriété ismobile.
     * 
     * @return
     *     possible object is
     *     {@link String }
     *     
     */
    public String getISMOBILE() {
        return ismobile;
    }

    /**
     * Définit la valeur de la propriété ismobile.
     * 
     * @param value
     *     allowed object is
     *     {@link String }
     *     
     */
    public void setISMOBILE(String value) {
        this.ismobile = value;
    }

}

==> eam-wshub-proxyclient-11.7-2-sources.jar: net/datastream/schemas/mp_fields/COMMENTAUDITITEM_Type.java <==

package net.datastream.schemas.mp_fields;

import javax.xml.bind.annotation.XmlAccessType;
import javax.xml.bind.annotation.XmlAccessorType;
import javax.xml.bind.annotation.XmlElement;
import javax.xml.bind.annotation.XmlType;
import org.openapplications.oagis_segments.DATETIME;


/**
 * <p>Java class for COMMENTAUDITITEM_Type complex type.
 * 
 * <p>The following schema fragment specifies the expected content contained within this class.
 * 
 * <pre>
 * &lt;complexType name="COMMENTAUDITITEM_Type">
 *   &lt;complexContent>
 *     &lt;extension base="{http://schemas.datastream.net/MP_fields}COMMENT_Type">
 *       &lt;sequence>
 *         &lt;element name="DELETEDDATE" type="{http://www.openapplications.org/oagis_segments}DATETIME" minOccurs="0"/>
 *         &lt;element name="DELETEDBY" type="{http://schemas.datastream.net/MP_fields}USERID_Type" minOccurs="0"/>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}ISMOBILE" minOccurs="0"/>
 *       &lt;/sequence>
 *     &lt;/extension>
 *   &lt;/complexContent>
 * &lt;/complexType>
 * </pre>
 * 
 * 
 */
@XmlAccessorType(XmlAccessType.FIELD)
@XmlType(name = "COMMENTAUDITITEM_Type", propOrder = {
    "deleteddate",
    "deletedby",
    "ismobile"
})
public class COMMENTAUDITITEM_Type
    extends COMMENT_Type
{

    @XmlElement(name = "DELETEDDATE")
    protected DATETIME deleteddate;
    @XmlElement(name = "DELETEDBY")
    protected USERID_Type deletedby;
    @XmlElement(name = "ISMOBILE")
    protected String ismobile;

    /**
     * Gets the value of the deleteddate property.
     * 
     * @return
     *     possible object is
     *     {@link DATETIME }
     *     
     */
    public DATETIME getDELETEDDATE() {
        return deleteddate;
    }

    /**
     * Sets the value of the deleteddate property.
     * 
     * @param value
     *     allowed object is
     *     {@link DATETIME }
     *     
     */
    public void setDELETEDDATE(DATETIME value) {
        this.deleteddate = value;
    }

    /**
     * Gets the value of the deletedby property.
     * 
     * @return
     *     possible object is
     *     {@link USERID_Type }
     *     
     */
    public USERID_Type getDELETEDBY() {
        return deletedby;
    }

    /**
     * Sets the value of the deletedby property.
     * 
     * @param value
     *     allowed object is
     *     {@link USERID_Type }
     *     
     */
    public void setDELETEDBY(USERID_Type value) {
        this.deletedby = value;
    }

    /**
     * Gets the value of the ismobile property.
     * 
     * @return
     *     possible object is
     *     {@link String }
     *     
     */
    public String getISMOBILE() {
        return ismobile;
    }

    /**
     * Sets the value of the ismobile property.
     * 
     * @param value
     *     allowed object is
     *     {@link String }
     *     
     */
    public void setISMOBILE(String value) {
        this.ismobile = value;
    }

}
